/** \file main.c
 *
 * \brief GPIO: LEDs.
 *
 * This example program switches the LED on and off.
 *
 * The relevant registers are:
 * - DIR: Data Direction Register
 * - OUT: Data Output Value
 *
 * Please see modules 4.2.1 and 4.3.3 for more information.
 * 
 * \author    Wolfgang Neff
 * \version   1.0
 * \date      2018-07-14
 *
 * \par History
 *      Created: 2018-07-14
 */

// Include the modules used by this program.
#include <avr/io.h>
#include <util/delay.h>

#include "board.h"

// At first we start with the initial state: LED off. Then we want that the LED blinks. The
// definitions for the microcontroller come from module avr/io.h. The definition for the 
// delay routine comes from util/delay and the definitions for the microcontroller board
// come from board.h. avr/io.h and util/delay are system modules. board.h is a user module.
/***** This is the main program. *****/
int main(void)
{
	/***** Initialize Hardware *****/
	// At first we specify the initial state. The LED is active low (see board.h).
	// So we have to set the pin to switch it off.
    LED_PORT.OUT = LED_PIN_bm;
	// LEDs need power to light up. Therefore the LED pin must be output.
    LED_PORT.DIR = LED_PIN_bm;
	/***** Use Hardware *****/
	// The super loop is the section where the hardware is used and controlled.
	// We want that the LED is blinking.
    while(1)
    {
		// Switch the LED on. The LED is active low. So we clear the pin.
		// Please see module 4.3.1 for the details on bit manipulation.
        LED_PORT.OUT &= ~LED_PIN_bm;
		// Let's wait a bit.
	    _delay_ms(500);
		// Switch LED off again.
        LED_PORT.OUT |= LED_PIN_bm;
		// Let's wait again a bit.
	    _delay_ms(500);
    }
}

