/** \file main.c
 *
 * \brief GPIO: push-button.
 *
 * This example program checks if the push-button is pressed.
 *
 * The relevant registers are:
 * - DIR: Data Direction Register
 * - IN: Data Input Value Register
 * - PINnCTRL: Pin n Configuration Register
 *
 * Please see modules 4.2.1 and 4.3.3 for more information.
 *
 * \author    Wolfgang Neff
 * \version   1.0
 * \date      2018-07-14
 *
 * \par History
 *      Created: 2018-07-14
 */

#include <avr/io.h>
#include "board.h"

// We want to switch the LED on if the button is pressed and
// we want to switch it off if the button is not pressed.
int main(void)
{
	/***** Initialize the LED. *****/
    LED_PORT.DIR = LED_PIN_bm;
	/***** Initialize the push-buttons. *****/
	// The push-button is active low and requires a pull resistor.
	// So we activate the pull up resistor.
	BUTTON_PINCTRL = PORT_PULLUPEN_bm;
	/***** Super loop *****/
	// This is the control section.
    while(1)
    {
		// We check if the button is pressed. The button is active low.
		// Please see module 4.3.1 for the details on bit manipulation.
        if (!(BUTTON_PORT.IN & BUTTON_PIN_bm)) {
			// Switch LED on.
			LED_PORT.OUT &= ~LED_PIN_bm;
		}
        else {
			// Switch LED off.
			LED_PORT.OUT |= LED_PIN_bm;
		}
	}
}
