/** \file main.c
 *
 * \brief GPIO: debouncing push-buttons.
 *
 * This example program demonstrates the use of a debouncing routine.
 *
 * Please see module 4.2.3 for more information.
 *
 * \note
 * This example uses a user defined module. A user module consists of two files: the header file (.h)
 * and the source code (.c). Both files must be copied into the folder where main.c is. Then both
 * files have to be included into the project: right click on the project (not the solution), select
 * Add/Existing item..., add the files. 
 *
 * \author    Wolfgang Neff
 * \version   1.0
 * \date      2018-07-14
 *
 * \par History
 *      Created: 2018-07-14
 */

#include <avr/io.h>

#include "board.h"
#include "switch.h"

// We use the push-button to switch the LED on and off. As we use the button as a switch
// we have to debounce. We use a piece of software to debounce. The debounce routine is
// called SWITCH_PRESSED() and is defined in module switch.h.
int main(void)
{
    // Initialize the LED.
    LED_PORT.OUT = LED_PIN_bm;
    LED_PORT.DIR = LED_PIN_bm;                
	// Initialize the button.
	BUTTON_PINCTRL = PORT_PULLUPEN_bm;
	while(1)
	{
		// Use the push-button to toggle the LED.
		if (SWITCH_PRESSED()) {
			LED_PORT.OUT ^= LED_PIN_bm;
		}
	}
}
