/*
 * switch.c
 *
 * Version: 1.0
 * Created: 2018-07-17
 *  Author: Wolfgang Neff
 *
 * This code is based on Peter Dannegger. Please refer to
 * http://www.mikrocontroller.net/topic/164194#1566921.
 *
 */ 

#include <avr/io.h>
#include <util/delay.h>

#include "switch.h"
 
void switch_init(void)
{
    BUTTON_PORT.DIRCLR = BUTTON_PIN_bm;
    BUTTON_PINCTRL = PORT_PULLUPEN_bm;
}

uint8_t switch_debounce(volatile PORT_t* port, uint8_t mask, uint8_t key)
{
	static uint8_t flag = 0;
	if (flag & (1<<key)) {                    /* check for key release */
		for (int i=0; i< 250; i++) {
			if (!(port->IN & mask)) return 0; /* bounce detected */
			_delay_us(100);                   /* 250*100 us = 25 ms */
		}
		flag &= ~(1<<key);                    /* clear press flag */
	}
	else {                                    /* check for key press */
		for (int i=0; i< 250; i++) {
			if (port->IN & mask) return 0;    /* bounce detected */
			_delay_us(100);                   /* 250*100 us = 25 ms */
		}
		flag |= (1<<key);                     /* set press flag */
	}
	return flag & (1<<key);                   /* return key state */
}
