/** \file console.h
 *
 * \brief Connect stdio with the virtual COM port.
 *
 * This module connects stdio with the virtual COM port so that the
 * standard input/output functions such as getchar, putchar, gets,
 * puts, printf and scanf can be used with a terminal such as PuTTY.
 *
 * \author    Wolfgang Neff
 * \version   1.0
 * \date      2018-07-15
 *
 * \par History
 *      Created: 2018-07-15
 *
 * \note Serial line parameters: 115200 8N1
 */

#ifndef CONSOLE_H_
#define CONSOLE_H_

#include <stdio.h>

#ifdef __cplusplus
extern "C"
{
#endif

/// <summary>Initialize module.</summary>
/// <remarks>
/// This routine initializes the virtual COM port and connects
/// it with stdio.
/// </remarks>
void console_init(void);

/// <summary>Clear screen.</summary>
/// <remarks>
/// This routine erases the screen with the background color and moves
/// the cursor to its home position. This routine requires an ANSI/VT100
/// compatible terminal.
/// </remarks>
void console_clear(void);

#ifdef __cplusplus
}
#endif

#endif /* CONSOLE_H_ */
